aboutsummaryrefslogtreecommitdiffhomepage
path: root/patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch
diff options
context:
space:
mode:
authorNassim Jahnke <[email protected]>2024-02-23 14:37:33 +0100
committerGitHub <[email protected]>2024-02-23 14:37:33 +0100
commit71c84c8132a463ca26978b852bbbf33ae42cd4ce (patch)
treebbdde5e8056d16ba6778e56165db39b1f6d44468 /patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch
parent3ea95efdebba7254e842dec66214f71de4721993 (diff)
downloadPaper-71c84c8132a463ca26978b852bbbf33ae42cd4ce.tar.gz
Paper-71c84c8132a463ca26978b852bbbf33ae42cd4ce.zip
Updated Upstream (Bukkit/CraftBukkit/Spigot) (#10277)
Upstream has released updates that appear to apply and compile correctly. This update has not been tested by PaperMC and as with ANY update, please do your own testing Bukkit Changes: 9a80d38c SPIGOT-336, SPIGOT-3366, SPIGOT-5768, SPIGOT-6409, SPIGOT-6861, PR-722: Add EntityRemoveEvent 258086d9 SPIGOT-7417, PR-967: Add Sign#getTargetSide and Sign#getAllowedEditor ffaba051 SPIGOT-7584: Add missing Tag.ITEMS_NON_FLAMMABLE_WOOD CraftBukkit Changes: 98b6c1ac7 SPIGOT-7589 Fix NullPointerException when bans expire a2736ddb0 SPIGOT-336, SPIGOT-3366, SPIGOT-5768, SPIGOT-6409, SPIGOT-6861, PR-1008: Add EntityRemoveEvent 5bf12cb89 SPIGOT-7565: Throw a more descriptive error message when a developer tries to spawn an entity from a CraftBukkit class 76d95fe7e SPIGOT-7417, PR-1343: Add Sign#getTargetSide and Sign#getAllowedEditor Spigot Changes: e9ec5485 Rebuild patches f1b62e0c Rebuild patches
Diffstat (limited to 'patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch')
-rw-r--r--patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch14
1 files changed, 7 insertions, 7 deletions
diff --git a/patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch b/patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch
index 251043d71f..56f1ab09f3 100644
--- a/patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch
+++ b/patches/server/0824-Fixes-and-additions-to-the-SpawnReason-API.patch
@@ -21,17 +21,17 @@ index 035af9ccf679a562203a4a2c4f2b38098c57b492..557df259ae54defb43e475e10fc47328
@Nullable
diff --git a/src/main/java/net/minecraft/world/entity/projectile/DragonFireball.java b/src/main/java/net/minecraft/world/entity/projectile/DragonFireball.java
-index 61a36c4e97ee532e53eee4da00a9aa7e4b3438f5..d3b4420e664fedf86d107e819056d2e20f9c0722 100644
+index 58723ea75f7db9bf3889b99139669b14a284a3a1..6bf11d526b82403e9a5443ac77645cf2b4bc1ad8 100644
--- a/src/main/java/net/minecraft/world/entity/projectile/DragonFireball.java
+++ b/src/main/java/net/minecraft/world/entity/projectile/DragonFireball.java
-@@ -54,7 +54,7 @@ public class DragonFireball extends AbstractHurtingProjectile {
+@@ -64,7 +64,7 @@ public class DragonFireball extends AbstractHurtingProjectile {
- if (new com.destroystokyo.paper.event.entity.EnderDragonFireballHitEvent((org.bukkit.entity.DragonFireball) this.getBukkitEntity(), list.stream().map(LivingEntity::getBukkitLivingEntity).collect(java.util.stream.Collectors.toList()), (org.bukkit.entity.AreaEffectCloud) areaEffectCloud.getBukkitEntity()).callEvent()) { // Paper - EnderDragon Events
+ if (new com.destroystokyo.paper.event.entity.EnderDragonFireballHitEvent((org.bukkit.entity.DragonFireball) this.getBukkitEntity(), list.stream().map(LivingEntity::getBukkitLivingEntity).collect(java.util.stream.Collectors.toList()), (org.bukkit.entity.AreaEffectCloud) entityareaeffectcloud.getBukkitEntity()).callEvent()) { // Paper - EnderDragon Events
this.level().levelEvent(2006, this.blockPosition(), this.isSilent() ? -1 : 1);
-- this.level().addFreshEntity(areaEffectCloud);
-+ this.level().addFreshEntity(areaEffectCloud, org.bukkit.event.entity.CreatureSpawnEvent.SpawnReason.EXPLOSION); // Paper - use correct spawn reason
- } else areaEffectCloud.discard(); // Paper - EnderDragon Events
- this.discard();
+- this.level().addFreshEntity(entityareaeffectcloud);
++ this.level().addFreshEntity(entityareaeffectcloud, org.bukkit.event.entity.CreatureSpawnEvent.SpawnReason.EXPLOSION); // Paper - use correct spawn reason
+ } else entityareaeffectcloud.discard(null); // Paper - EnderDragon Events
+ this.discard(EntityRemoveEvent.Cause.HIT); // CraftBukkit - add Bukkit remove cause
}
diff --git a/src/main/java/net/minecraft/world/level/block/FrogspawnBlock.java b/src/main/java/net/minecraft/world/level/block/FrogspawnBlock.java
index 4a1f2d326c4ece9da717a50b802af86fd9338a0b..94618709e742ebe1a7893d418124e309eaab6c5f 100644